@@ -137,7 +137,7 @@ sub make_exe {
 		push @cmd, '-M', 'Tie::Hash::NamedCapture';
 	}
 
-	push @cmd, '-M', 'ORLite::Migrate::Patch';
+	push @cmd, '-M', 'Padre::DB::Migrate::Patch';
 
 	print join( ' ', @cmd ) . "\n";
 	system(@cmd);
