@@ -12,10 +12,13 @@ use Pod::Abstract                    ();
 use Padre::DocBrowser::document      ();
 use Padre::DocBrowser::PseudoPerldoc ();
 
-our $VERSION = '0.54';
+our $VERSION = '0.55';
 
-use Class::XSAccessor constructor => 'new', getters => {
-	get_provider => 'provider',
+use Class::XSAccessor {
+	constructor => 'new',
+	getters     => {
+		get_provider => 'provider',
+	},
 };
 
 sub provider_for {
