@@ -53,7 +53,7 @@ use YAML::Tiny     ();
 use Padre::DB      ();
 use Padre::Wx      ();
 
-our $VERSION    = '0.54';
+our $VERSION    = '0.55';
 our $COMPATIBLE = '0.43';
 
 # Link plug-ins back to their IDE
@@ -156,11 +156,6 @@ sub plugin_directory_locale {
 	return File::Spec->catdir( $share, 'locale' );
 }
 
-# NOTE Back-compatibility
-sub plugin_locale_directory {
-	shift->plugin_directory_locale(@_);
-}
-
 =pod
 
 =head2 C<plugin_icon>
