@@ -10,7 +10,7 @@ use YAML::Tiny     ();
 use Padre::Config  ();
 use Padre::Current ();
 
-our $VERSION = '0.54';
+our $VERSION = '0.55';
 
 use Class::XSAccessor {
 	getters => {
@@ -30,7 +30,21 @@ sub class {
 	my $class = shift;
 	my $root  = shift;
 	unless ( -d $root ) {
-		Carp::croak("Project directory '$root' does not exist");
+
+		#		Carp::croak("Project directory '$root' does not exist");
+		# Project root doesn't exist, this might cause problems
+		# but croaking completly crashs Padre. Fix for #819
+		Padre->ide->wx->main->error(
+			sprintf(
+				Wx::gettext(
+					      'Project directory %s does not exist (any longer). '
+						. 'This is fatal and will cause problems, please close or '
+						. 'save-as this file unless you know what you are doing.'
+				),
+				$root
+			)
+		);
+		return 'Padre::Project::Null';
 	}
 	if ( -f File::Spec->catfile( $root, 'Makefile.PL' ) ) {
 		return 'Padre::Project::Perl';
@@ -61,10 +75,12 @@ sub new {
 
 	# Check the root directory
 	unless ( defined $self->root ) {
-		croak("Did not provide a root directory");
+		Carp::croak("Did not provide a root directory");
 	}
 	unless ( -d $self->root ) {
-		croak( "Root directory " . $self->root . " does not exist" );
+		return undef;
+
+		#		Carp::croak( "Root directory " . $self->root . " does not exist" );
 	}
 
 	# Check for a padre.yml file
