@@ -113,7 +113,7 @@ use IO::String   ();
 use Scalar::Util ();
 use Params::Util '_INSTANCE';
 
-our $VERSION = '0.54';
+our $VERSION = '0.55';
 
 # TO DO: Why are there require?
 require Padre;
@@ -127,7 +127,9 @@ BEGIN {
 	}
 }
 
-use Class::XSAccessor constructor => 'new';
+use Class::XSAccessor {
+	constructor => 'new',
+};
 
 # set up the stdout/stderr printing events
 our $STDOUT_EVENT : shared = Wx::NewEventType();
