@@ -31,14 +31,20 @@ use HTTP::Request  ();
 use HTTP::Response ();
 use Padre::Task    ();
 
-our $VERSION = '0.54';
+our $VERSION = '0.55';
 our @ISA     = 'Padre::Task';
 
-use Class::XSAccessor getters => {
-	request  => 'request',
-	response => 'response',
+use Class::XSAccessor {
+	getters => {
+		request  => 'request',
+		response => 'response',
+	}
 };
 
+
+
+
+
 ######################################################################
 # Constructor
 
