@@ -4,16 +4,26 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION        = '0.54';
+our $VERSION        = '0.55';
 our @ISA            = 'Padre::Task';
 our $thread_running = 0;
 
 # accessors
-use Class::XSAccessor accessors => {
-	_directory                => '_directory',                # searched directory
-	_matched_files            => '_matched_files',            # matched files list
-	_skip_vcs_files           => '_skip_vcs_files',           # Skip VCS files menu item
-	_skip_using_manifest_skip => '_skip_using_manifest_skip', # Skip using MANIFEST.SKIP menu item
+use Class::XSAccessor {
+	accessors => {
+
+		# Searched directory
+		_directory => '_directory',
+
+		# Matched files list
+		_matched_files => '_matched_files',
+
+		# Skip VCS files menu item
+		_skip_vcs_files => '_skip_vcs_files',
+
+		# Skip using MANIFEST.SKIP menu item
+		_skip_using_manifest_skip => '_skip_using_manifest_skip',
+	}
 };
 
 #
