@@ -6,14 +6,16 @@ use warnings;
 use Padre::Wx       ();
 use Padre::Wx::Icon ();
 
-our $VERSION = '0.54';
+our $VERSION = '0.55';
 our @ISA     = 'Wx::Dialog';
 
-use Class::XSAccessor accessors => {
-	_butrun => '_butrun', # run button
-	_combo  => '_combo',  # combo box
-	_names  => '_names',  # list of all recent commands
-	_sizer  => '_sizer',  # the window sizer
+use Class::XSAccessor {
+	accessors => {
+		_butrun => '_butrun', # run button
+		_combo  => '_combo',  # combo box
+		_names  => '_names',  # list of all recent commands
+		_sizer  => '_sizer',  # the window sizer
+	}
 };
 
 # -- constructor
