@@ -13,10 +13,12 @@ use Class::Adapter::Builder
 	NEW      => 'Wx::Menu',
 	AUTOLOAD => 'PUBLIC';
 
-our $VERSION = '0.54';
+our $VERSION = '0.55';
 
-use Class::XSAccessor getters => {
-	wx => 'OBJECT',
+use Class::XSAccessor {
+	getters => {
+		wx => 'OBJECT',
+	}
 };
 
 # Default implementation of refresh
