@@ -19,27 +19,30 @@ use Padre::Wx::Menu::Plugins ();
 use Padre::Wx::Menu::Window  ();
 use Padre::Wx::Menu::Help    ();
 
-our $VERSION = '0.54';
+our $VERSION = '0.55';
 
 #####################################################################
 # Construction, Setup, and Accessors
 
-use Class::XSAccessor getters => {
-	wx   => 'wx',
-	main => 'main',
+use Class::XSAccessor {
+	getters => {
+		wx       => 'wx',
+		main     => 'main',
+		mimetype => 'mimetype',
 
-	# Don't add accessors to here until they have been
-	# upgraded to be fully encapsulated classes.
-	file     => 'file',
-	edit     => 'edit',
-	search   => 'search',
-	view     => 'view',
-	perl     => 'perl',
-	refactor => 'refactor',
-	run      => 'run',
-	plugins  => 'plugins',
-	window   => 'window',
-	help     => 'help',
+		# Don't add accessors to here until they have been
+		# upgraded to be fully encapsulated classes.
+		file     => 'file',
+		edit     => 'edit',
+		search   => 'search',
+		view     => 'view',
+		perl     => 'perl',
+		refactor => 'refactor',
+		run      => 'run',
+		plugins  => 'plugins',
+		window   => 'window',
+		help     => 'help',
+	}
 };
 
 sub new {
@@ -52,6 +55,8 @@ sub new {
 		# Link back to the main window
 		main => $main,
 
+		mimetype => '',
+
 		# The number of menus in the default set.
 		# That is, EXCLUDING the special Perl menu.
 		default => 8,
@@ -91,13 +96,20 @@ sub new {
 # Reflowing the Menu
 
 sub refresh {
-	my $self    = shift;
-	my $plugins = shift;
+	my $self     = shift;
+	my $plugins  = shift;
+	my $current  = _CURRENT(@_);
+	my $main     = $self->main;
+	my $config   = $current->config;
+	my $document = $current->document;
+	my $mimetype = $document ? $document->get_mimetype : '';
 
-	my $main   = $self->main;
-	my $config = $main->ide->config;
-
-	my $current = _CURRENT(@_);
+	# Shortcut if no change
+	if ( $self->{mimetype} and $mimetype and $self->{mimetype} eq $mimetype ) {
+		return 1;
+	} else {
+		$self->{mimetype} = $mimetype;
+	}
 
 	# This is a version between fully configurable menus and the old fixed ones, it
 	# isn't made to stay forever, but it's working for now
@@ -128,10 +140,11 @@ sub refresh {
 		}
 	}
 
+	# Throw in an Wx repainting lock to kill off any gui flicker
+	my $lock = $main->lock('UPDATE');
+
 	my $count = -1;
-
 	for my $item (@items) {
-
 		if ( $item =~ /^menu\.(.+)$/ ) {
 			my $menu = $1;
 
