@@ -8,11 +8,13 @@ use Padre::Wx      ();
 use Padre::Current ();
 use Padre::Logger;
 
-our $VERSION = '0.54';
+our $VERSION = '0.55';
 our @ISA     = 'Wx::TreeCtrl';
 
-use Class::XSAccessor accessors => {
-	force_next => 'force_next',
+use Class::XSAccessor {
+	accessors => {
+		force_next => 'force_next',
+	}
 };
 
 sub new {
